@@ -1,5 +1,7 @@
 # Copyright PA Knowledge Ltd 2021
 
+from pysisl.deep_merger import ListTuple
+
 
 class SislEncoder:
 
@@ -25,7 +27,7 @@ class SislEncoder:
             return {
                 int: lambda val: f"!int \"{val}\"",
                 float: lambda val: f"!float \"{val}\"",
-                str: lambda val: f"!str \"{val}\"",
+                str: lambda val: f"!str \"{cls._escape(val)}\"",
                 bool: lambda val: f"!bool \"{str(val).lower()}\"",
                 list: lambda val: f"!list {{{cls._construct_sisl_for_list_object(val)}}}",
                 dict: lambda val: f"!obj {cls.dumps(val)}",
@@ -34,11 +36,21 @@ class SislEncoder:
         except KeyError as err:
             raise TypeValidationError(err)
 
+    @classmethod
+    def _escape(cls, value: str):
+        return value.replace('\\', '\\\\').replace(r'"', r'\"')
+
     @classmethod
     def _construct_sisl_for_list_object(cls, value):
-        return ', '.join([cls._construct_sisl_triple(f"_{i}", value[i]) for i in range(len(value))])
+        return ', '.join([cls._construct_sisl_triple(*cls._check_if_list_tuple(i, item)) for i, item in enumerate(value)])
+
+    @classmethod
+    def _check_if_list_tuple(cls, index, list_item):
+        if type(list_item) is ListTuple:
+            return f"_{list_item.position}", list_item.value
+
+        return f"_{index}", list_item
 
 
 class TypeValidationError(Exception):
     pass
-
